@@ -6,6 +6,6 @@ from .architectures import (
     build_xlmr_transformer_model_v1,
     build_pytorch_checkpoint_loader_v1,
 )
-from .hf_loader import build_hf_encoder_loader_v1
+from .hf_loader import build_hf_transformer_encoder_loader_v1
 from .scalar_weight import build_scalar_weight_v1
 from .with_strided_spans import build_with_strided_spans_v1
