@@ -16,7 +16,7 @@ from curated_transformers.models.architectures import (
     build_bert_transformer_model_v1,
     build_roberta_transformer_model_v1,
 )
-from curated_transformers.models.hf_loader import build_hf_encoder_loader_v1
+from curated_transformers.models.hf_loader import build_hf_transformer_encoder_loader_v1
 from curated_transformers.models.with_strided_spans import (
     build_with_strided_spans_v1,
 )
@@ -228,7 +228,7 @@ def test_bert_transformer_pipe_against_hf():
         with_spans=build_with_strided_spans_v1(),
         vocab_size=28996,
     )
-    model.get_ref("transformer").init = build_hf_encoder_loader_v1(
+    model.get_ref("transformer").init = build_hf_transformer_encoder_loader_v1(
         name="bert-base-cased"
     )
     model.get_ref("piece_encoder").init = build_hf_piece_encoder_loader_v1(
@@ -267,7 +267,7 @@ def test_camembert_transformer_pipe_against_hf():
         with_spans=build_with_strided_spans_v1(),
         vocab_size=32005,
     )
-    model.get_ref("transformer").init = build_hf_encoder_loader_v1(
+    model.get_ref("transformer").init = build_hf_transformer_encoder_loader_v1(
         name="camembert-base"
     )
     model.get_ref("piece_encoder").init = build_hf_piece_encoder_loader_v1(
@@ -306,7 +306,9 @@ def test_roberta_transformer_pipe_against_hf():
         with_spans=build_with_strided_spans_v1(),
         vocab_size=50265,
     )
-    model.get_ref("transformer").init = build_hf_encoder_loader_v1(name="roberta-base")
+    model.get_ref("transformer").init = build_hf_transformer_encoder_loader_v1(
+        name="roberta-base"
+    )
     model.get_ref("piece_encoder").init = build_hf_piece_encoder_loader_v1(
         name="roberta-base"
     )
@@ -345,7 +347,7 @@ def test_xlmr_transformer_pipe_against_hf():
         with_spans=build_with_strided_spans_v1(),
         vocab_size=250002,
     )
-    model.get_ref("transformer").init = build_hf_encoder_loader_v1(
+    model.get_ref("transformer").init = build_hf_transformer_encoder_loader_v1(
         name="xlm-roberta-base"
     )
     model.get_ref("piece_encoder").init = build_hf_piece_encoder_loader_v1(
@@ -421,7 +423,7 @@ def test_transformer_pipe_outputs():
         with_spans=build_with_strided_spans_v1(),
         vocab_size=250002,
     )
-    model.get_ref("transformer").init = build_hf_encoder_loader_v1(
+    model.get_ref("transformer").init = build_hf_transformer_encoder_loader_v1(
         name="xlm-roberta-base"
     )
     model.get_ref("piece_encoder").init = build_hf_piece_encoder_loader_v1(
