@@ -11,6 +11,7 @@ from .types import (
     Tok2PiecesModelT,
     Tok2PiecesOutT,
 )
+from ..errors import Errors
 
 
 @serialize_attr.register(ByteBPEProcessor)
@@ -56,13 +57,13 @@ def byte_bpe_encoder_forward(
     unk_piece: str = model.attrs["unk_piece"]
     bos_id = bbp.piece_id(bos_piece)
     if bos_id is None:
-        raise ValueError("Vocabulary does not have BOS piece")
+        raise ValueError(Errors.E019.format(piece="BOS"))
     eos_id = bbp.piece_id(eos_piece)
     if eos_id is None:
-        raise ValueError("Vocabulary does not have EOS piece")
+        raise ValueError(Errors.E019.format(piece="EOS"))
     unk_id = bbp.piece_id(unk_piece)
     if unk_id is None:
-        raise ValueError("Vocabulary does not have UNK piece")
+        raise ValueError(Errors.E019.format(piece="UNK"))
 
     pieces = []
     for doc in X:
